@@ -331,6 +331,12 @@ def test_differential_pressure_meter_solver_misc():
 
     m = differential_pressure_meter_solver(D=0.07366, D2=0.05, P1=200000.0,  P2=183000.0, rho=1.2, mu=0.00011, k=1.33, meter_type='ISO 5167 orifice', taps='D')
     assert_close(m, 0.2695835697819371)
+    
+    m_expect = 7.9299168920313425
+    m = differential_pressure_meter_solver(D=0.07366, D2=0.05, P1=200000.0, P2=183000.0, rho=999.1, mu=0.0011, k=1.33, meter_type='ISO 5167 orifice', taps='D', epsilon_specified=1)
+    assert_close(m, m_expect)
+    m = differential_pressure_meter_solver(D=0.07366, D2=0.05, P1=200000.0, P2=183000.0, rho=999.1, mu=0.0011, meter_type='ISO 5167 orifice', taps='D', epsilon_specified=1)
+    assert_close(m, m_expect)
 
 def test_unspecified_meter_C_specified():
     for t in ('unspecified meter', 'ISO 5167 orifice'):
@@ -408,6 +414,8 @@ def test_nozzle_expansibility():
     assert_close(epsilon, 0.9945702344566746)
 
     assert_close(nozzle_expansibility(D=0.0739, Do=0.0222, P1=1E5, P2=1e5, k=1.4), 1, rtol=1e-14)
+    
+    assert_close(nozzle_expansibility(D=0.0739, Do=0.0222, P1=1E5, P2=9.9E4, k=1), 0.9924074233062772, rtol=1e-13)
 
 def test_C_long_radius_nozzle():
     C = C_long_radius_nozzle(D=0.07391, Do=0.0422, rho=1.2, mu=1.8E-5, m=0.1)
